<?php

namespace Iwaydev\TransNgClient;

use Illuminate\Support\ServiceProvider;

/**
 * Провайдер TransNG
 *
 * @package Iwaydev\TransNgClient
 */
class TransNgServiceProvider extends ServiceProvider
{
    /**
     * Register services.
     *
     * @return void
     */
    public function register(): void
    {
        parent::register();

        $this->setDefaultLogChannel();

        $this->registerSender();
    }

    /**
     * Добавляет в конфиг канал для логирования, если отсутствует
     */
    protected function setDefaultLogChannel(): void
    {
        if (!config()->has('logging.channels.trans_ng')) {
            config()->set('logging.channels.trans_ng', require __DIR__ . '/../config/log-trans-ng.php');
        }
    }

    /**
     * Регистрирует сендер для общения с сервисов авторизации
     */
    protected function registerSender(): void
    {
        $this->app->singleton(TransNgClient::class, function ($app) {
            return new TransNgClient(
                config('senders.trans-ng.connection.url'),
                config('senders.trans-ng.connection.api_version'),
                cache()->store(),
                config('senders.trans-ng.cache.lifetime'),
                logs('trans_ng'),
                $app->request->header('X-UUID', null)
            );
        });
    }

    /**
     * Bootstrap services.
     *
     * @return void
     */
    public function boot(): void
    {
        if ($this->app->runningInConsole()) {
            $this->publishes([
                __DIR__ . '/../config/trans-ng.php' => config_path('senders/trans-ng.php'),
            ], 'config');

            $this->publishes([
                __DIR__ . '/TransNgServiceProvider.php' => app_path('Providers/TransNgServiceProvider.php'),
            ], 'provider');
        }
    }
}
